<?php
/**
* @version 1.2.0
* @package RSEvents! 1.2.0
* @copyright (C) 2009 www.rsjoomla.com
* @license GPL, http://www.gnu.org/copyleft/gpl.html
*/

// no direct access
defined('_JEXEC') or die('Restricted access');

global $_PLUGINS;
$_PLUGINS->registerFunction( 'onBeforegetFieldRow', 'onBeforegetFieldRow', 'getRseventsTab' );
$_PLUGINS->registerUserFieldTypes( array('rseventsstatus'	=> 'CBfield_rseventsstatus') );
$_PLUGINS->registerUserFieldParams();

class CBfield_rseventsstatus extends cbFieldHandler {
	
	/**
	 * Accessor:
	 * Returns a field in specified format
	 *
	 * @param  moscomprofilerFields  $field
	 * @param  moscomprofilerUser    $user
	 * @param  string                $output  'html', 'xml', 'json', 'php', 'csvheader', 'csv', 'rss', 'fieldslist', 'htmledit'
	 * @param  string                $reason  'profile' for user profile view, 'edit' for profile edit, 'register' for registration, 'search' for searches, 'list' for user-lists
	 * @param  int                   $list_compare_types   IF reason == 'search' : 0 : simple 'is' search, 1 : advanced search with modes, 2 : simple 'any' search
	 * @return mixed                
	 */
	function getField( &$field, &$user, $output, $reason, $list_compare_types ) 
	{
		global $ueConfig;
		
		static $stats								=	array();
		$value										=	null;

		if ( is_object( $user ) && $user->id ) {
			if ( ! isset( $stats[$user->id] ) ) {
				global $_PLUGINS;
				$params								=	array( &$user );
				$stats[$user->id]					=	$_PLUGINS->call( $this->getPluginId(), '', 'getRseventsTab', $params );
			}
			if ( isset( $stats[$user->id][$field->name] ) ) {
				$value								=	$stats[$user->id][$field->name];
			} else {
				$value								=	$ueConfig['emptyFieldsText'];
			}
			
		}

		switch ( $output ) {
			case 'html':
			case 'rss':
				return $this->_formatFieldOutput( $field->name, $value, $output, false );
			break;
			case 'htmledit':
				return null;
			break;
			default:
				return $this->_formatFieldOutput( $field->name, $value, $output, false );
			break;
		}
	}
}


class getRseventsTab extends cbTabHandler {
		
	/**
	* Constructor
	*/
	function getRseventsTab() 
	{
		$this->cbTabHandler();
	}
	
	/**
	* Generates the HTML to display the user profile tab
	* @param  moscomprofilerTab   $tab       the tab database entry
	* @param  moscomprofilerUser  $user      the user being displayed
	* @param  int                 $ui        1 for front-end, 2 for back-end
	* @return mixed                          either string HTML for tab content, or false if ErrorMSG generated
	*/
	function getDisplayTab( $tab, $user, $ui ) 
	{
		$db			=& JFactory::getDBO();
		$language 	=& JFactory::getLanguage();
		$params		= $this->params;
		$limit 		= $params->get('limit',5);
		$ordering	= $params->get('ordering','ASC');
		$target		= $params->get('target',1);
		$target		= $target ? '' : 'target="_blank"';
		$itemid		= $params->get('itemid','');
		$itemid		= empty($itemid) ? '' : '&Itemid='.(int) $itemid;
		
		//load language 
		$language->load('com_rsevents');
		
		//get events
		$return 		= '';
		$created 		= $this->getCreatedEvents($limit,$user->id,$ordering);
		$subscribed		= $this->getSubscribedEvents($limit,$user->id,$ordering);

		//get the date mask
		$db->setQuery("SELECT ConfigValue FROM #__rsevents_config WHERE ConfigName = 'global.dateformat' ");
		$datemask = $db->loadResult();
		
		$return .= '<h4 style="border-bottom:1px solid">'.JText::_('RSE_CB_MY_EVENTS').'</h4>';
		if (empty($created))
			$return .= JText::_('RSE_CB_NO_EVENTS');
		else 
		{
			$return .= '<table width="100%">';
			$return .= '<thead>';
			$return .= '<tr>';
			$return .= '<th>'.JText::_('RSE_CB_EVENT_NAME').'</th>';
			$return .= '<th>'.JText::_('RSE_CB_EVENT_START').'</th>';
			$return .= '<th>'.JText::_('RSE_CB_EVENT_END').'</th>';
			$return .= '<th>'.JText::_('RSE_CB_EVENT_LOCATION').'</th>';
			$return .= '</tr>';
			$return .= '</thead>';
			$return .= '<tbody>';
			
			foreach ($created as $event)
			{
				$return .= '<tr>';
				$return .= '<td><a '.$target.' href="'.JRoute::_('index.php?option=com_rsevents&view=events&layout=show&cid='.$event->IdEvent.':'.JFilterOutput::stringURLSafe($event->EventName).$itemid,false).'">'.$event->EventName.'</a></td>';
				$return .= '<td>'.date($datemask,$event->EventStartDate).'</a></td>';
				$return .= '<td>'.date($datemask,$event->EventEndDate).'</a></td>';
				$return .= '<td><a '.$target.' href="'.JRoute::_('index.php?option=com_rsevents&view=locations&layout=show&cid='.$event->IdLocation.'&IdEvent='.$event->IdEvent.$itemid,false).'">'.$event->LocationName.'</a></td>';
				$return .= '</tr>';
			}
			
			$return .= '</tbody>';
			$return .= '</table>';
		}
		
		
		
		
		$return .= '<h4 style="border-bottom:1px solid">'.JText::_('RSE_CB_MY_SUBSCRIPTIONS').'</h4>';
		if (empty($subscribed))
			$return .= JText::_('RSE_CB_NO_SUBSCRIPTION');
		else
		{
			$return .= '<table width="100%">';
			$return .= '<thead>';
			$return .= '<tr>';
			$return .= '<th>'.JText::_('RSE_CB_EVENT_NAME').'</th>';
			$return .= '<th>'.JText::_('RSE_CB_EVENT_START').'</th>';
			$return .= '<th>'.JText::_('RSE_CB_EVENT_END').'</th>';
			$return .= '<th>'.JText::_('RSE_CB_EVENT_LOCATION').'</th>';
			$return .= '</tr>';
			$return .= '</thead>';
			$return .= '<tbody>';
			
			foreach ($subscribed as $event)
			{
				$return .= '<tr>';
				$return .= '<td><a '.$target.' href="'.JRoute::_('index.php?option=com_rsevents&view=events&layout=show&cid='.$event->IdEvent.':'.JFilterOutput::stringURLSafe($event->EventName).$itemid,false).'">'.$event->EventName.'</a></td>';
				$return .= '<td>'.date($datemask,$event->EventStartDate).'</a></td>';
				$return .= '<td>'.date($datemask,$event->EventEndDate).'</a></td>';
				$return .= '<td><a '.$target.' href="'.JRoute::_('index.php?option=com_rsevents&view=locations&layout=show&cid='.$event->IdLocation.'&IdEvent='.$event->IdEvent.$itemid,false).'">'.$event->LocationName.'</a></td>';
				$return .= '</tr>';
			}
			
			$return .= '</tbody>';
			$return .= '</table>';
		}
		
		return $return;
	}
	
	
	//get the list of events that the current user has created
	function getCreatedEvents($limit,$id,$order)
	{
		$db = JFactory::getDBO();
		
		$db->setQuery("SELECT e.IdEvent, e.EventName, e.EventStartDate, e.EventEndDate, l.IdLocation, l.LocationName, l.LocationCity, l.LocationAddress FROM #__rsevents_events e LEFT JOIN #__rsevents_locations l ON l.IdLocation = e.IdLocation WHERE 1=1 AND e.EventType = 1 AND e.published = 1 AND e.IdUser = '".$id."' ORDER BY e.EventStartDate ".$order." LIMIT ".(int) $limit);
		
		return $db->loadObjectList();
	}
	
	//get the list of all the events the current user has subscribed
	function getSubscribedEvents($limit,$id,$order)
	{
		$db = JFactory::getDBO();
		
		$db->setQuery("SELECT e.IdEvent, e.EventName, e.EventStartDate, e.EventEndDate, l.IdLocation, l.LocationName, l.LocationCity, l.LocationAddress FROM #__rsevents_events e LEFT JOIN #__rsevents_locations l ON l.IdLocation = e.IdLocation LEFT JOIN #__rsevents_subscriptions s ON s.IdEvent = e.IdEvent WHERE 1=1 AND e.published = 1 AND s.SubscriptionState = 1 AND e.EventType = 1 AND s.IdUser = '".$id."' ORDER BY e.EventStartDate ".$order." LIMIT ".(int) $limit);
		
		return $db->loadObjectList();
	}
	
}
?>